@@ -28,7 +28,7 @@ def struct_info_func(args):
 
     labels = xyz_py.add_numbers(labels)
 
-    f_head = os.path.splitext(args.xyz_f_name)[0]
+    f_head = os.path.splitext(args.xyz_file)[0]
 
     if args.cutoffs:
         cutoffs = parse_cutoffs(args.cutoffs)
